package com.qmth.cqb.base.service;

import static org.springframework.data.domain.ExampleMatcher.GenericPropertyMatchers.startsWith;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import com.qmth.cqb.base.dao.CourseRepo;
import com.qmth.cqb.base.model.Course;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

/**
 * Created by songyue on 16/12/28.
 */
@Service
public class CourseService {
	
	@Autowired
	CourseRepo courseRepo;
	
    @Autowired
    MongoTemplate mongoTemplate;
    
    /**
     * 查询所有课程
     * @param searchCondition
     * @param curPage
     * @param pageSize
     * @return
     */
    public PagingAndSortingResponse<Course> findAll(Course searchCondition, int curPage, int pageSize){
        Page<Course> courseList = courseRepo.findAll(Example.of(searchCondition),new PageRequest(curPage-1,pageSize));
        return new PagingAndSortingResponse<Course>(courseList.getNumber(),courseList.getSize(),
        		courseList.getTotalPages(),courseList.getTotalElements(),courseList.getContent());
    }

    
    /**
     * 保存课程
     * @param course
     * @return
     */
    public NormalResponse saveCourse(Course course){
    	Course tempCourse = courseRepo.save(course);
        if(tempCourse != null){
            return new NormalResponse(HttpStatus.OK.toString(),"success");
        }else{
            return new NormalResponse(HttpStatus.INTERNAL_SERVER_ERROR.toString(),"保存失败");
        }
    }
    
    /**
     * 删除课程
     * @param courseId
     * @return
     */
    public NormalResponse deleteCourse(String courseId){
    	courseRepo.delete(courseId);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }

    
    /**
     * 根据课程名称或者课程No.查找课程
     * @param 
     * @return
     */
    public List<Course> findCoursesByKeyword(String keyword){
    	keyword = keyword.replace("(","").replace(")", "");		
    	Criteria likeNo = Criteria.where("courseNo").regex(keyword);//模糊匹配相当于SQL中“%Keyword%”
	    Criteria likeName = Criteria.where("courseName").regex(keyword);
	    Query query = new Query(new Criteria().orOperator(likeName,likeNo));
	    List<Course> courselist = mongoTemplate.find(query, Course.class);
	    return courselist;
       
    }
}
