package com.qmth.cqb.base.web;

import com.google.gson.Gson;
import com.qmth.cqb.base.dao.RoleRepo;
import com.qmth.cqb.base.model.Role;
import com.qmth.cqb.base.service.RoleService;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

/**
 * Created by songyue on 16/12/26.
 */
@RestController
@RequestMapping("${api_cqb}/")
public class RoleController {
    @Autowired
    Gson gson;

    @Autowired
    RoleRepo roleRepo;

    @Autowired
    RoleService roleService;

    /**
     * 获取角色
     * @param role_id
     * @return
     */
    @GetMapping(value = "/role/{role_id}")
    public Role getRoleById(@PathVariable String role_id){
        return roleRepo.findById(role_id);
    }

    /**
     * 获取全部角色
     * @return
     */
    @GetMapping(value = "/role/all/{curPage}/{pageSize}")
    public PagingAndSortingResponse<Role> getAllRole(@ModelAttribute Role searchCondition,@PathVariable int curPage,@PathVariable int pageSize){
        return roleService.findAll(searchCondition,new PageRequest(curPage - 1,pageSize));
    }

    /**
     * 更新角色
     * @param role
     * @return
     */
    @PutMapping(value = "/role")
    public NormalResponse updateRole(@ModelAttribute Role role){
        roleRepo.save(role);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }

    /**
     * 新增角色
     * @param role
     * @return
     */
    @PostMapping(value = "/role")
    public NormalResponse addRole(@ModelAttribute Role role){
        roleRepo.save(role);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }

    /**
     * 删除角色
     * @param role_id
     * @return
     */
    @DeleteMapping(value = "/role/{role_id}")
    public NormalResponse removeRole(@PathVariable String role_id){
        roleRepo.delete(role_id);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }}
