package com.qmth.cqb.base.web;

import com.google.gson.Gson;
import com.qmth.cqb.base.dao.UserRepo;
import com.qmth.cqb.base.model.User;
import com.qmth.cqb.base.service.UserService;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

/**
 * Created by songyue on 16/12/26.
 */
@RestController
@RequestMapping("${api_cqb}/")
public class UserController {
    @Autowired
    Gson gson;

    @Autowired
    UserRepo userRepo;

    @Autowired
    UserService userService;

    /**
     * 获取用户
     * @param user_id
     * @return
     */
    @GetMapping(value = "/user/{user_id}")
    public User getUserById(@PathVariable String user_id){
        return userRepo.findById(user_id);
    }

    /**
     * 获取全部用户
     * @return
     */
    @GetMapping(value = "/user/all/{curPage}/{paseSize}")
    public PagingAndSortingResponse<User> getAllUser(@ModelAttribute User searchCondition, @PathVariable int curPage, @PathVariable int pageSize){
        return userService.findAll(searchCondition,new PageRequest(curPage - 1,pageSize));
    }

    /**
     * 更新用户
     * @param user
     * @return
     */
    @PutMapping(value = "/user")
    public NormalResponse updateUser(@ModelAttribute User user){
        userRepo.save(user);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }

    /**
     * 新增用户
     * @param user
     * @return
     */
    @PostMapping(value = "/user")
    public NormalResponse addUser(@ModelAttribute User user){
        userRepo.save(user);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }

    /**
     * 删除用户
     * @param user_id
     * @return
     */
    @DeleteMapping(value = "/user/{user_id}")
    public NormalResponse removeUser(@PathVariable String user_id){
        userRepo.delete(user_id);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }
}
