package com.qmth.cqb.question.web;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.qmth.cqb.question.dao.QuesRepo;
import com.qmth.cqb.question.model.QuesOption;
import com.qmth.cqb.question.model.QuestionType;
import com.qmth.cqb.question.model.Question;
import com.qmth.cqb.question.model.QuestionSearchCondition;
import com.qmth.cqb.question.service.QuesService;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

import io.swagger.annotations.ApiOperation;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * Created by songyue on 16/12/28.
 */
@RestController
@RequestMapping("${api_cqb}/")
public class QuesController {

    @Autowired
    QuesService quesService;

    @Autowired
    QuesRepo quesRepo;

    @Autowired
    Gson gson;

    /**
     * 获取试题
     * @param id
     * @return
     */
    @ApiOperation(value="获取单个试题",notes="获取单个试题")
    @GetMapping(value = "/question/{id}")
    public ResponseEntity getQuesById(@PathVariable String id){
        return new ResponseEntity(quesRepo.findOne(id),HttpStatus.OK);
    }

    /**
     * 分页查询试题
     * @return
     */
    @ApiOperation(value="分页查询试题",notes="分页查询试题")
    @GetMapping(value = "/question/{curPage}/{pageSize}")
    public ResponseEntity getAllQuestion(@ModelAttribute QuestionSearchCondition searchCondition,                                              @PathVariable int curPage,
                                         @PathVariable int pageSize){
      return new ResponseEntity(quesService.findAll(searchCondition, curPage, pageSize),
              HttpStatus.OK);
    }

    /**
     * 更新试题信息
     * @param 
     * @return
     */
    @ApiOperation(value="更新试题",notes="更新试题")
    @PutMapping(value = "/question")
    public ResponseEntity updateQuestion(@ModelAttribute Question question){
        return new ResponseEntity(quesRepo.save(question),HttpStatus.OK);
    	
    }

    /**
     * 新增试题
     * @param question
     * @return
     */
    @ApiOperation(value="新增试题",notes="新增试题")
    @PostMapping(value = "/question")
    public ResponseEntity addQuestion(@ModelAttribute Question question){
      return new ResponseEntity(quesRepo.save(question),HttpStatus.CREATED);
    }

    /**
     * 删除试题
     * @param id
     * @return
     */
    @ApiOperation(value="删除试题",notes="删除试题")
    @DeleteMapping(value = "/question/{id}")
    public ResponseEntity removeQuestion(@PathVariable String id){
    	quesRepo.delete(id);
    	return new ResponseEntity(HttpStatus.OK);
    }
}
